DnaClaudeConfig class

The Claude tool configuration (claude:).

Constructors

DnaClaudeConfig({List<String>? claudeMdInclude})
Creates the config.
const

Properties

claudeMdInclude List<String>?
Files/folders whose @-imports form the managed CLAUDE.md block; null = section absent.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited